==> zither-1.2.0.tar.gz: zither_prj/sitar/sitar_scan.h <==

#ifndef _SITAR_SCAN_H_
  #define _SITAR_SCAN_H_

  #include<time.h>

  #define BUF_URL 1024

  #define DEFAULT_TIMEOUT 4

  /* RESOLV DEBUG */
//  #define RESOLV_DEBUG

  /* SMTP SCAN DEBUG */
//  #define SMTP_BUG

  /* URL SCAN DEBUG */
//  #define URL_BUG

  /* ICMP SCAN DEBUG */
//  #define ICMP_BUG

  /* UDP SCAN DEBUG */
//  #define UDP_BUG

  /* TCP DEBUG  */
//  #define TCP_BUG 

  /* TCP DHW BUG  */
//  #define DHW_BUG 

  /* SNTP BUG */
//  #define SNTP_BUG                   

  /* SSL/TSL BUG */
//  #define SSL_BUG



  /* --- scan_icmp.c --- */
  char * scan_icmp(char *, char *, int, int *, int);

  /* --- scan_udpportc --- */
  char * scan_udp_connect(int , char *, char *, int, int *);

  /* --- scan_tcpport.c --- */
  char * scan_tcp_connect(int, char *, char *, int, int *);

  /* --- scan_url_connect.c --- */
  char * scan_url_connect(int, char *, char *, int, int *);

  /* --- scan_ssl_connect.c --- */
  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *);
  int count_memcpy3(char out[], char * data, int start, int plus);

  /* --- scan_smtpport.c --- */
  char * scan_smtp_connect(int, char *, char *, int, int *);
  char * resolvename_th(char *, char *, int, unsigned long *);
  char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *, char);
  char * out_resolvename(char *, char *, int, unsigned long *);
  unsigned long resolve_name(char *name);
  time_t cert_time_get(char * data);
  char * th_resolv(char * name, char * back, int interval, int out);

  /* --- scan_statport.c --- */
  char * scan_stat_connect(int, char *, char *, char *, int, int, int *);


  /* --- scan_dhwport.c --- */
  char * scan_dhw_connect(char *, int, char *, char *, int, int *);

  /* --- scan_sntp --- */
  char * scan_sntp_connect(int, char [], char *, int, int *);

  /* --- scan_host.c --- */
  char * scan_host(char *, char *, char *, int, int *);

  /* scan_urlport() */
  int urldompass_port(char *, char *, char *, int); 
  char * set_request(char *, char *, char *);
  int self_set_request(char *, char *, char *, int);
  char * check_recvdata(char *, char *, int *);
  int self_check_recvdata(char *, char *);

   char * scan_dns_connect(int, char *, char *, char *, int, int *, char);


#endif

==> zither-1.2.1.tar.gz: zither_prj/sitar/sitar_scan.h <==

#ifndef _SITAR_SCAN_H_
  #define _SITAR_SCAN_H_

  #include<time.h>

  #define BUF_URL 1024

  #define DEFAULT_TIMEOUT 4

  /* RESOLV DEBUG */
//  #define RESOLV_DEBUG

  /* SMTP SCAN DEBUG */
//  #define SMTP_BUG

  /* URL SCAN DEBUG */
//  #define URL_BUG

  /* ICMP SCAN DEBUG */
//  #define ICMP_BUG

  /* UDP SCAN DEBUG */
//  #define UDP_BUG

  /* TCP DEBUG  */
//  #define TCP_BUG 

  /* TCP DHW BUG  */
//  #define DHW_BUG 

  /* SNTP BUG */
//  #define SNTP_BUG                   

  /* SSL/TSL BUG */
//  #define SSL_BUG



  /* --- scan_icmp.c --- */
  char * scan_icmp(char *, char *, int, int *, int);

  /* --- scan_udpportc --- */
  char * scan_udp_connect(int , char *, char *, int, int *);

  /* --- scan_tcpport.c --- */
  char * scan_tcp_connect(int, char *, char *, int, int *);

  /* --- scan_url_connect.c --- */
  char * scan_url_connect(int, char *, char *, int, int *, char);

  /* --- scan_ssl_connect.c --- */
  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *);
  int count_memcpy3(char out[], char * data, int start, int plus);

  char * scan_mysql_command(char * backdata, char * query, char * server, char * username, char * passwd, char * database, int port, int timeout, int * pst, char * plai);


  /* --- scan_smtpport.c --- */
  char * scan_smtp_connect(int, char *, char *, int, int *);
  char * resolvename_th(char *, char *, int, unsigned long *);
  char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *, char);
  char * out_resolvename(char *, char *, int, unsigned long *);
  unsigned long resolve_name(char *name);
  time_t cert_time_get(char * data);
  char * th_resolv(char * name, char * back, int interval, int out);

  /* --- scan_statport.c --- */
  char * scan_stat_connect(int, char *, char *, char *, int, int, int *);


  /* --- scan_dhwport.c --- */
  char * scan_dhw_connect(char *, int, char *, char *, int, int *);

  /* --- scan_sntp --- */
  char * scan_sntp_connect(int, char [], char *, int, int *);

  /* --- scan_host.c --- */
  char * scan_host(char *, char *, char *, int, int *);

  /* scan_urlport() */
  int urldompass_port(char *, char *, char *, int); 
  char * set_request(char *, char *, char *);
  int self_set_request(char *, char *, char *, int, char *);
  char * check_recvdata(char *, char *, int *);
  int self_check_recvdata(char *, char *);

   char * scan_dns_connect(int, char *, char *, char *, int, int *, char);


#endif
